@@ -11,27 +11,27 @@ class ConnectionStatus(Enum):
 
     @property
     def is_closed(self) -> bool:
-        return self == self.CLOSED
+        return self == ConnectionStatus.CLOSED
 
     @property
     def is_closing(self) -> bool:
-        return self == self.CLOSING
+        return self == ConnectionStatus.CLOSING
 
     @property
     def is_init(self) -> bool:
-        return self == self.INIT
+        return self == ConnectionStatus.INIT
 
     @property
     def is_connected(self) -> bool:
-        return self == self.CONNECTED
+        return self == ConnectionStatus.CONNECTED
 
     @property
     def is_subscribed(self) -> bool:
-        return self == self.SUBSCRIBED
+        return self == ConnectionStatus.SUBSCRIBED
 
     @property
     def is_reconnecting(self) -> bool:
-        return self == self.RECONNECTING
+        return self == ConnectionStatus.RECONNECTING
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return not self.is_closed and not self.is_closing and not self.is_init
